# Python Package for DS-Student-Resources Companion Norebook
This package was built to help students achieve a better learning experience in the Data Science Program

<hr style="border: 0; height: 1px; background-image: linear-gradient(to right, rgba(0, 0, 0, 0), rgba(0, 0, 0, 0.75), rgba(0, 0, 0, 0));"/>

## Curriculum 

| | 
|:--|
|[DS101-Basic-Statistics](DS101-Basic-Statistics/DS101-Syllabus.md)| 
|[DS102-Statistical-Programming-in-R](DS102-Statistical-Programming-in-R/DS102-Syllabus.md)|
|[DS103-Metrics-and-Data-Processing](DS103-Metrics-and-Data-Processing/DS103-Syllabus.md)|
|[DS104-Data-Wrangling-and-Visualization](DS104-Data-Wrangling-and-Visualization/DS104-Syllabus.md)|
|[DS105-Intermediate-Statistics](DS105-Intermediate-Statistics/DS105-Syllabus.md)|
|[DS106-Machine-Learning](DS106-Machine-Learning/DS106-Syllabus.md)|
|[DS107-Big-Data](DS107-Big-Data/DS107-Syllabus.md)|
|[DS108-Databases](DS108-Databases/DS108-Syllabus.md)|
|[DS109-Python](DS109-Python/DS109-Syllabus.md)|
|[DS110-Final-Project](DS110-Final-Project/DS110-Syllabus.md)|


<hr style="border: 0; height: 1px; background-image: linear-gradient(to right, rgba(0, 0, 0, 0), rgba(0, 0, 0, 0.75), rgba(0, 0, 0, 0));"/>



